@@ -1,5 +1,9 @@
 # LU MAU BOKEP GAK ? 🤣
 
+from pyrogram import *
+from pyrogram import Client
+from pyrogram.types import *
+
 bokep = "https://t.me/+R-oIEJKFZ0pkYzgx"
 bocil = ""
 tiktok = ""
@@ -8,7 +12,7 @@ kontol = "kangcopybot"
 ANAK_KONTOL = kontol
 ANAK_ANJING = bokep
 
-# 
+
 absen = [
     "**Hadir bang** 😁",
     "**Hadir kak** 😉",
@@ -19,6 +23,9 @@ absen = [
     "**Hadir kak maap telat** 🥺",
 ]
 
+def hacking(client, Client, message: Message):
+    hacking = message.reply_text
+
 blockyou = 1447438514
 
 """
